Changelog
=========

0.2.1 -- <UNRELEASED>
-------------------


0.2 -- 2011.04.29
-------------------

* feature: added suport to be used as a library
* bug: fixed some setup related bugs
* bug: fix windows drive calculation
* bug: reworked tests, all tests are now passing
